==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/WebComponentDateValueChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebComponentDateValueChangedEventArgsDescription } from "./WebComponentDateValueChangedEventArgsDescription";
/**
 * @hidden
 */
var WebComponentDateValueChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebComponentDateValueChangedEventArgsDescriptionMetadata, _super);
    function WebComponentDateValueChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebComponentDateValueChangedEventArgsDescriptionMetadata.b = function (a) {
        if (WebComponentDateValueChangedEventArgsDescriptionMetadata.a == null) {
            WebComponentDateValueChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebComponentDateValueChangedEventArgsDescriptionMetadata.c(WebComponentDateValueChangedEventArgsDescriptionMetadata.a);
        }
        if (a.g(WebComponentDateValueChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(WebComponentDateValueChangedEventArgsDescriptionMetadata.a);
    };
    WebComponentDateValueChangedEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ComponentDateValueChangedEventArgs");
        a.item("Detail", "Date");
    };
    WebComponentDateValueChangedEventArgsDescriptionMetadata.d = function (a) {
        WebComponentDateValueChangedEventArgsDescriptionMetadata.b(a);
        a.u("WebComponentDateValueChangedEventArgs", function () { return new WebComponentDateValueChangedEventArgsDescription(); });
        a.t("WebComponentDateValueChangedEventArgs", WebComponentDateValueChangedEventArgsDescriptionMetadata.a);
    };
    WebComponentDateValueChangedEventArgsDescriptionMetadata.$t = markType(WebComponentDateValueChangedEventArgsDescriptionMetadata, 'WebComponentDateValueChangedEventArgsDescriptionMetadata');
    WebComponentDateValueChangedEventArgsDescriptionMetadata.a = null;
    return WebComponentDateValueChangedEventArgsDescriptionMetadata;
}(Base));
export { WebComponentDateValueChangedEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebComponentDateValueChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebComponentDateValueChangedEventArgsDescription } from "./WebComponentDateValueChangedEventArgsDescription";
/**
 * @hidden
 */
var WebComponentDateValueChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebComponentDateValueChangedEventArgsDescriptionMetadata, _super);
    function WebComponentDateValueChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebComponentDateValueChangedEventArgsDescriptionMetadata.b = function (a) {
        if (WebComponentDateValueChangedEventArgsDescriptionMetadata.a == null) {
            WebComponentDateValueChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebComponentDateValueChangedEventArgsDescriptionMetadata.c(WebComponentDateValueChangedEventArgsDescriptionMetadata.a);
        }
        if (a.j(WebComponentDateValueChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(WebComponentDateValueChangedEventArgsDescriptionMetadata.a);
    };
    WebComponentDateValueChangedEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ComponentDateValueChangedEventArgs");
        a.item("Detail", "Date");
    };
    WebComponentDateValueChangedEventArgsDescriptionMetadata.d = function (a) {
        WebComponentDateValueChangedEventArgsDescriptionMetadata.b(a);
        a.aa("WebComponentDateValueChangedEventArgs", function () { return new WebComponentDateValueChangedEventArgsDescription(); });
        a.z("WebComponentDateValueChangedEventArgs", WebComponentDateValueChangedEventArgsDescriptionMetadata.a);
    };
    WebComponentDateValueChangedEventArgsDescriptionMetadata.$t = markType(WebComponentDateValueChangedEventArgsDescriptionMetadata, 'WebComponentDateValueChangedEventArgsDescriptionMetadata');
    WebComponentDateValueChangedEventArgsDescriptionMetadata.a = null;
    return WebComponentDateValueChangedEventArgsDescriptionMetadata;
}(Base));
export { WebComponentDateValueChangedEventArgsDescriptionMetadata };
